var base_2object__macros_8h =
[
    [ "IMP_GENERIC_OBJECT", "base_2object__macros_8h.html#a5cf901338b87b309ff320a5f84d57fca", null ],
    [ "IMP_NEW", "base_2object__macros_8h.html#ab148ba5f570e72971b3053e37ab3b412", null ],
    [ "IMP_OBJECT_METHODS", "base_2object__macros_8h.html#abae59f482ba9e87af96a36c47b276aa5", null ],
    [ "IMP_OBJECT_NO_WARNING", "base_2object__macros_8h.html#a0c234197b0819ef3a769b1bc7ccdc898", null ],
    [ "IMP_OBJECTS", "base_2object__macros_8h.html#a8ca3f8c401b6cb40e6fef25ed09e3c40", null ]
];